// -----------------------------------------------------------------------------
//
//  Gmsh GEO
//
// -----------------------------------------------------------------------------

//Use the following line to generate the mesh (.inp (abaqus))
//gmsh bar2section.geo  -3 -o mesh.inp

h = 0.125;  //mesh size
hcrack = 0.05; //mesh size near crack

// ------------------------------------------------------
// ------------------------------------------------------
// A)Geometry Definition: 1)Points 
//                        2)Lines 
//                        3)Curve 
//                        4)Surface 

// ------------------------------------------------------
// A1)Points Definitions: 
//
//         P8*---*P7
//           |   |  
//           |   |
//           |   |  
//           |   |
//         P9*   *P6 
//            \ /
//         P10* *P5      
//            | |
//         P11* *P4
//            / \ 
//        P12*   *P3  
//           |   |  
//           |   |
//           |   |  
//           |   |  
//         P1*---*P2
//
//    |Y
//    |
//    ---X   Dimensions:   1 x 1 x 0.01
// Z /
//

//           -----Coordinates--
//Points:    ----X,------Y,---Z,
Point(1)   ={ -0.5,   -5.0,   0,  h};
Point(2)   ={  0.5,   -5.0,   0,  h};
Point(3)   ={  0.5,   -1.0,   0,  h};
Point(4)   ={  0.25,  -1.0,   0,  h};
Point(5)   ={  0.25,   1.0,   0,  h};
Point(6)   ={  0.5,    1.0,   0,  h};
Point(7)   ={  0.5,    5.0,   0,  h};
Point(8)   ={ -0.5,    5.0,   0,  h};
Point(9)   ={ -0.5,    1.0,   0,  h};
Point(10)  ={ -0.25,   1.0,   0,  h};
Point(11)  ={ -0.25,  -1.0,   0,  h};
Point(12)  ={ -0.5,   -1.0,   0,  h};

// ------------------------------------------------------
// A2)Lines Definition
//
//            <-L7
//           *---*
//           |   |  
//           |   | ^
//       L8  |   | L6  
//           |   |
//           *   *   ^
//      L9    \ /   /  L5
//            * *      
//      L10\/ | | /\ L4
//            * *
//       L11  / \     L3
//           *   *  
//           |   |  
//           |   | ^
//       L12 |   | L2  
//           |   |  
//           *---*
//            L1->

Line(1)  = { 1,  2};  //L1:from P1 to P2: P1*--L1-->*P2
Line(2)  = { 2,  3};
Line(3)  = { 3,  4};
Line(4)  = { 4,  5};
Line(5)  = { 5,  6};
Line(6)  = { 6,  7};
Line(7)  = { 7,  8};
Line(8)  = { 8,  9};
Line(9)  = { 9, 10};
Line(10) = {10, 11};
Line(11) = {11, 12};
Line(12) = {12,  1};


// ------------------------------------------------------
// A3)Curve Definition
//
//           *-<-*
//           |   |  
//           |   /\ 
//          \/   |   
//           |   |
//           *   *   
//            \ /   
//            * *      
//            | | 
//            * *
//            / \     
//           *   *  
//           |   |  
//           |   /\  
//          \/   |  
//           |   |  
//           *->-*
//

Curve Loop(5) = {1,2,3,4,5,6,7,8,9,10,11,12};  //C5: through lines L1,L2,...,L7

// ------------------------------------------------------
// A4)Surface Definition
//
//           *---*
//           |   |
//           |   |
//           |   |
//           |   |
//           *   *
//            \ /
//            * *
//            | |
//            * *
//            / \
//           *   *
//           |   |
//           |S6 |
//           |   |
//           |   |
//           *---*

Plane Surface(6) = {5};  //  Curve loop 5 C5 --> Surface S6
Recombine Surface {6};



// ------------------------------------------------------
// ------------------------------------------------------
// B)Mesh Generation: 1)Mesh size Box1 
//                    2)Mesh size Box2
//                    3)Mesh min(Box1,Box2)
//                    3)Extrude Mesh 
//                    4)Mesh Algorithm  


// ------------------------------------------------------
// B1) Mesh size Box1
//
//        *-------------------* 
//        |                   | 
//        |                   |
//        |                   |
//        *    -----------    *
//             |hcrack F6|      (Field[6])
//        *    -----------    * 
//        |                   |
//        |                   |
//        |                   |
//        *-------------------*

Field[6]      =    Box;
Field[6].VIn  = hcrack;
Field[6].VOut =      h;

Field[6].XMin = -0.25;
Field[6].XMax =  0.25;
Field[6].YMin = -1.0;
Field[6].YMax =  1.0;

Background Field    = 6;

// ------------------------------------------------------
// B5)Mesh Algorithm
Geometry.Tolerance = 1e-12;

// ------------------------------------------------------
// B4)Extrude Mesh

//     {X, Y,    Z}    Surface
Extrude{0, 0,  1.0}{Surface{6}; Layers{{1},{1}};Recombine;}


// ------------------------------------------------------
// B5)Mesh Algorithm

